==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ForwardPluginFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface ForwardPluginFluent<A extends ForwardPluginFluent<A>> extends Fluent<A>{
  public String getPolicy();
  public A withPolicy(String policy);
  public Boolean hasPolicy();
  public A addToUpstreams(Integer index,String item);
  public A setToUpstreams(Integer index,String item);
  public A addToUpstreams(java.lang.String... items);
  public A addAllToUpstreams(Collection<String> items);
  public A removeFromUpstreams(java.lang.String... items);
  public A removeAllFromUpstreams(Collection<String> items);
  public List<String> getUpstreams();
  public String getUpstream(Integer index);
  public String getFirstUpstream();
  public String getLastUpstream();
  public String getMatchingUpstream(Predicate<String> predicate);
  public Boolean hasMatchingUpstream(Predicate<String> predicate);
  public A withUpstreams(List<String> upstreams);
  public A withUpstreams(java.lang.String... upstreams);
  public Boolean hasUpstreams();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> openshift-model-operator-6.7.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ForwardPluginFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ForwardPluginFluent<A extends ForwardPluginFluent<A>> extends Fluent<A>{
  public String getPolicy();
  public A withPolicy(String policy);
  public Boolean hasPolicy();
  public A addToUpstreams(int index,String item);
  public A setToUpstreams(int index,String item);
  public A addToUpstreams(java.lang.String... items);
  public A addAllToUpstreams(Collection<String> items);
  public A removeFromUpstreams(java.lang.String... items);
  public A removeAllFromUpstreams(Collection<String> items);
  public List<String> getUpstreams();
  public String getUpstream(int index);
  public String getFirstUpstream();
  public String getLastUpstream();
  public String getMatchingUpstream(Predicate<String> predicate);
  public Boolean hasMatchingUpstream(Predicate<String> predicate);
  public A withUpstreams(List<String> upstreams);
  public A withUpstreams(java.lang.String... upstreams);
  public Boolean hasUpstreams();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
